@@ -634,7 +634,7 @@ break_while:
 }
 
 void
-for_files (char *dirname, char *mask, void callback (char *file))
+for_files (const char *dirname, const char *mask, void callback (char *file))
 {
 	GDir *dir;
 	const gchar *entry_name;
